@@ -114,7 +114,9 @@ def get_request_ids_by_workload_id(workload_id, session=None):
 
 
 @read_session
-def get_requests(request_id=None, workload_id=None, with_detail=False, with_processing=False, with_metadata=False, to_json=False, session=None):
+def get_requests(request_id=None, workload_id=None, with_detail=False,
+                 with_request=False, with_transform=False, with_processing=False,
+                 with_metadata=False, to_json=False, session=None):
     """
     Get a request or raise a NoObject exception.
 
@@ -128,6 +130,7 @@ def get_requests(request_id=None, workload_id=None, with_detail=False, with_proc
     """
     return orm_requests.get_requests(request_id=request_id, workload_id=workload_id,
                                      with_detail=with_detail, with_metadata=with_metadata,
+                                     with_request=with_request, with_transform=with_transform,
                                      with_processing=with_processing,
                                      to_json=to_json, session=session)
 
